@@ -163,8 +163,8 @@ namespace Cairo {
 			// except in the case of Win64 where sizeof(long)
 			// is 32 bits
 			//
-			int ptr_size = IntPtr.Size;
-
+			int ptr_size = Marshal.SizeOf (typeof (IntPtr));
+			
 			PlatformID platform = Environment.OSVersion.Platform;
 			if (platform == PlatformID.Win32NT ||
 			    platform == PlatformID.Win32S ||
@@ -252,7 +252,7 @@ namespace Cairo {
                         }
                 }
                 
-		[Obsolete("Use SetSourceColor")]
+                //FIXME: obsolete this property
                 public Cairo.Color Color {
 			set { 
 				NativeMethods.cairo_set_source_rgba (state, value.R, value.G, value.B, value.A);
@@ -386,11 +386,6 @@ namespace Cairo {
 		public uint ReferenceCount {
 			get { return NativeMethods.cairo_get_reference_count (state); }
 		}
-		
-		public void SetSourceColor (Color color)
-		{
-			NativeMethods.cairo_set_source_rgba (state, color.R, color.G, color.B, color.A);
-		}
 
 		public void SetSourceRGB (double r, double g, double b)
 		{
