@@ -81,6 +81,9 @@ namespace GLib {
 
 		static GType ()
 		{
+			if (!GLib.Thread.Supported)
+				GLib.Thread.Init ();
+
 			g_type_init ();
 
 			Register (GType.Char, typeof (sbyte));
