@@ -31,23 +31,9 @@ namespace GLib {
 		//this is a static class
 		private Global () {}
 
-		internal static bool IsWindowsPlatform {
-			get {
-				switch (Environment.OSVersion.Platform) {
-				case PlatformID.Win32NT:
-				case PlatformID.Win32S:
-				case PlatformID.Win32Windows:
-				case PlatformID.WinCE:
-					return true;
-				default:
-					return false;
-				}
-			}
-		}
-
 		public static string ProgramName {
 			get {
-				return GLib.Marshaller.Utf8PtrToString (g_get_prgname());
+				return GLib.Marshaller.PtrToStringGFree(g_get_prgname());
 			}
 			set { 
 				IntPtr native_name = GLib.Marshaller.StringToPtrGStrdup (value);
@@ -56,15 +42,15 @@ namespace GLib {
 			}
 		}
 
-		[DllImport("libglib-2.0-0.dll", CallingConvention=CallingConvention.Cdecl)]
+		[DllImport("libglib-2.0-0.dll")]
 		static extern void g_set_prgname (IntPtr name);
 
-		[DllImport("libglib-2.0-0.dll", CallingConvention=CallingConvention.Cdecl)]
+		[DllImport("libglib-2.0-0.dll")]
 		static extern IntPtr g_get_prgname ();
 
 		public static string ApplicationName {
 			get {
-				return GLib.Marshaller.Utf8PtrToString (g_get_application_name());	
+				return GLib.Marshaller.PtrToStringGFree(g_get_application_name());	
 			}
 			set {
 				IntPtr native_name = GLib.Marshaller.StringToPtrGStrdup (value);
@@ -73,10 +59,10 @@ namespace GLib {
 			}
 		}
 
-		[DllImport("libglib-2.0-0.dll", CallingConvention=CallingConvention.Cdecl)]
+		[DllImport("libglib-2.0-0.dll")]
 		static extern void g_set_application_name (IntPtr name);
 
-		[DllImport("libglib-2.0-0.dll", CallingConvention=CallingConvention.Cdecl)]
+		[DllImport("libglib-2.0-0.dll")]
 		static extern IntPtr g_get_application_name ();
 	}
 }
